<?php //Admin Post: admin-post.php

add_action( 'admin_notices', 'blm_admin_post_notice' );
add_action( 'add_meta_boxes', 'blm_admin_post_location_display' );
add_action( 'save_post', 'blm_admin_post_save', 100, 2 );

/*
* blm_admin_post_scripts
* Add CSS and JS to the admin post page
*/
function blm_admin_post_scripts( $hook ) {

	// Check valid page type
	if ( ! blm_admin_post_validtype( $hook ) ) {
		return true;
	}

	// Get current Google API key
	$blm_setting_google_api_key = esc_attr( get_option( 'blm_setting_google_api_key' ) );

	// Load scripts if key is available
	if ( $blm_setting_google_api_key ) {
		wp_enqueue_script( 'blm_meta_js_google', 'https://maps.googleapis.com/maps/api/js?key=' . $blm_setting_google_api_key );
		wp_enqueue_script( 'blm_meta_js_geocode', plugins_url( 'js/geocode.js', __FILE__ ), null, blm_lib_get_version() );
		wp_enqueue_script( 'blm_meta_js_adminpost', plugins_url( 'js/admin-post.js', __FILE__ ), array( 'jquery' ), blm_lib_get_version() );
		wp_enqueue_style( 'blm_meta_css_main', plugins_url( 'css/admin-post.css', __FILE__ ), null, blm_lib_get_version() );
	}
}// blm_admin_post_scripts

/*
* blm_admin_post_notice
* Add a message to the header of the admin
* Note: In block editor (Gutenberg), this doesn't show by default
* Note cont. A redundant message is displayed in the Post Location section
*/
function blm_admin_post_notice() {
	// Initialize
	global $pagenow, $post;

	// Check valid and active post type
	$blm_post_type = get_option( 'blm_setting_posttype_' . get_post_type( $post ) );
	if ( ! blm_admin_post_validtype( $pagenow ) || ! $blm_post_type || 'none' === $blm_post_type ) {
		return false;
	}

	// Get API response notice
	$api_response = get_post_meta( $post->ID, 'blm_savepost_response', true );

	// Handle error
	if ( ! $api_response ) {
		return false;
	}

	//Decode current geotagging response
	$api_response = json_decode( $api_response, true );

	//Display response if error
	if ( $api_response['code'] !== 1 ) {
		echo '<div class="notice notice-error is-dismissible" data-code="' . esc_attr( $api_response['code'] ) . '"><p>Bloom: ' . esc_html( $api_response['message'] ) . '</p></div>';
	}

	return true;
}// blm_admin_post_notice

/*
* blm_admin_post_location_display
* Adds a location input to post editor
*/
function blm_admin_post_location_display() {
	// Initialize
	global $pagenow, $post;

	// Check valid and active post type
	$blm_post_type = get_option( 'blm_setting_posttype_' . get_post_type( $post ) );
	if ( ! blm_admin_post_validtype( $pagenow ) || ! $blm_post_type || 'none' === $blm_post_type ) {
		return false;
	}

	// Check for Google API key
	if ( ! get_option( 'blm_setting_google_api_key' ) ) {
		return false;
	}

	// Display location form
	add_action( 'admin_enqueue_scripts', 'blm_admin_post_scripts' );
	add_meta_box( 'blm_location_meta', __( 'Bloom: Post Location', 'location-textdomain' ), 'blm_admin_post_location_display_callback', null, 'advanced', 'high' );
}// blm_admin_post_location_display

/*
* blm_admin_post_location_display_callback
* Displays the location input in editor
*/
function blm_admin_post_location_display_callback( $post ) {

	// Fetch currently-saved post location data
	$blm_setting_google_api_key   = esc_attr( get_option( 'blm_setting_google_api_key' ) );
	$blm_post_location_formatted  = get_post_meta( $post->ID, 'blm_post_location_formatted', true );
	$blm_post_location_components = get_post_meta( $post->ID, 'blm_post_location_components', true );
	$blm_post_location_latitude   = get_post_meta( $post->ID, 'blm_post_location_latitude', true );
	$blm_post_location_longitude  = get_post_meta( $post->ID, 'blm_post_location_longitude', true );

	// Handle if no Google API key provided
	if ( ! $blm_setting_google_api_key ) {
		echo '<p>Enter your Google API Key on the Bloom Settings page in order to use this geotagging feature.</p>';
		return true;
	}

	// Nonce field
	wp_nonce_field( 'blm_post_nonce', 'blm_post_n' );

	// Handle API response notice if previously saved
	$api_response     = get_post_meta( $post->ID, 'blm_savepost_response', true );
	$has_api_response = false;

	if ( $api_response ) {
		//Decode current geotagging response
		$api_response = json_decode( $api_response, true );

		if ( isset( $api_response['code'] ) && isset( $api_response['message'] ) ) {
			$has_api_response = true;
		}
	}
	?>

	<div id="blm-meta-intro">

		<?php if ( $has_api_response ) { ?>
			<div id="blm-location-message" data-code="<?php echo esc_attr( $api_response['code'] ); ?>"><strong>Geotag Status:</strong> <?php echo esc_html( $api_response['message'] ); ?></div>
		<?php } ?>

		<p>Add the location discussed in this post.</p>
		<p>The post will be geotagged by <a href="https://www.bloom.li/advocacy/metadata" title="Bloom" target="_blank">inserting metadata</a> on the post's page and saving to Bloom to be used along with your web and email services.</p>
	</div>
	<div id="blm-location-selection-tool">
		<div id="blm-location-search">
			<div class="blm-search-title">Location Search</div>
			<div class="blm-search-body">
				<input type="text" id="blm_location_input" />
				<button type="button" id="blm-location-request" onClick="blmGeocode( 'blm_location_input', 'blm-location-results' );">Search</button>
				<div id="blm-location-results"></div>
			</div>
		</div>

		<div id="blm-location-choice" data-display="<?php echo ( $blm_post_location_formatted ) ? 1 : 0; ?>">
			<div class="blm-search-title">Location Selected<button type="button" id="blm-location-clear" onClick="blmClearLocation();">Clear</button><button type="button" id="blm-location-details" onClick="blmLocationDetailsChange('show');">Show Details</button></div>

			<div class="blm-search-body">
				<div id="blm-location-choice-value"><?php echo esc_html( $blm_post_location_formatted ); ?></div>
				<div id="blm-location-choice-components">
					<ul>
						<?php
						if ( $blm_post_location_components ) {
							$blm_post_lc_array = json_decode( $blm_post_location_components, true );

							if ( is_array( $blm_post_lc_array ) && ! empty( $blm_post_lc_array ) ) {
								foreach ( $blm_post_lc_array as $blm_post_lc_key => $blm_post_lc_value ) {
									echo '<li><strong>' . esc_html( ucfirst( str_replace( '_', ' ', $blm_post_lc_key ) ) ) . ':</strong> ' . esc_html( ( $blm_post_lc_value ? $blm_post_lc_value : 'None' ) ) . '</li>';
								}
							}
						}
						?>
					</ul>
				</div>
				<input type="hidden" name="blm_formatted_address" id="blm-formatted-address" value="<?php echo esc_attr( $blm_post_location_formatted ); ?>" />
				<input type="hidden" name="blm_address_components" id="blm-address-components" value="<?php echo esc_attr( base64_encode( $blm_post_location_components ) ); ?>" />
				<input type="hidden" name="blm_latitude" id="blm-latitude" value="<?php echo esc_attr( $blm_post_location_latitude ); ?>" />
				<input type="hidden" name="blm_longitude" id="blm-longitude" value="<?php echo esc_attr( $blm_post_location_longitude ); ?>" />
				<input type="hidden" name="blm_ua" id="blm-ua" />
			</div>
		</div>
	</div>

	<?php
}// blm_admin_post_location_display_callback

/*
* blm_admin_post_save
* Save the post on Bloom
*/
function blm_admin_post_save( $post_ID, $post ) {

	// Initialize
	global $pagenow;
	$has_location = false;
	$post_type    = get_post_type( $post );

	// Validate nonce
	if ( ! isset( $_POST['blm_post_n'] ) || ! wp_verify_nonce( sanitize_key( $_POST['blm_post_n'] ), 'blm_post_nonce' ) ) {
		return false;
	}

	// Validate page type
	if ( ! blm_admin_post_validtype( $pagenow ) ) {
		return true;
	}

	// Validate post type
	$blm_post_type = get_option( 'blm_setting_posttype_' . $post_type );
	if ( ! $blm_post_type || 'none' === $blm_post_type ) {
		return false;
	}

	// Sanitize input
	$input      = array();
	$input_vars = array(
		'blm_formatted_address',
		'blm_address_components',
		'blm_latitude',
		'blm_longitude',
		'blm_ua',
	);

	foreach ( $input_vars as $v ) {
		$input[ $v ] = null;

		// Check requirements
		if ( ! isset( $_POST[ $v ] ) ) {
			return false;
		}

		$input[ $v ] = sanitize_text_field( $_POST[ $v ] );
	}

	// Update location values
	update_post_meta( $post_ID, 'blm_post_location_formatted', $input['blm_formatted_address'] );
	update_post_meta( $post_ID, 'blm_post_location_components', base64_decode( $input['blm_address_components'] ) );
	update_post_meta( $post_ID, 'blm_post_location_latitude', $input['blm_latitude'] );
	update_post_meta( $post_ID, 'blm_post_location_longitude', $input['blm_longitude'] );

	// Check if location provided
	if ( $input['blm_formatted_address'] && $input['blm_address_components'] && $input['blm_latitude'] && $input['blm_longitude'] ) {
		$has_location = true;
	}

	// Save to Bloom only if published with a location
	if ( 'publish' !== $post->post_status || ! $has_location || wp_is_post_autosave( $post_ID ) ) {
		return blm_admin_post_save_reset();
	}

	// Get Bloom keys
	$blm_setting_bloom_api_key       = get_option( 'blm_setting_bloom_api_key' );
	$blm_setting_bloom_publisher_key = get_option( 'blm_setting_bloom_publisher_key' );
	$blm_setting_google_api_key      = get_option( 'blm_setting_google_api_key' );

	// Check key requirements
	if ( ! $blm_setting_bloom_api_key || ! $blm_setting_bloom_publisher_key || ! $blm_setting_google_api_key ) {
		// Update response
		update_post_meta(
			$post_ID,
			'blm_savepost_response',
			wp_json_encode(
				array(
					'code'    => 0,
					'message' => 'Keys were not provided in Bloom settings',
				)
			)
		);

		// Track anonymous geotagging
		if ( isset( $_SERVER['HTTP_HOST'] ) && isset( $_SERVER['REQUEST_URI'] ) ) {
			blm_lib_api_process(
				'info',
				array(
					'app_action' => 'anon_geotagging',
					'url'        => esc_url( sanitize_text_field( $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] ) ),
				)
			);
		}

		return true;
	}

	// Get location data
	$blm_post_location_formatted = get_post_meta( $post_ID, 'blm_post_location_formatted', true );
	$blm_post_location_latitude  = get_post_meta( $post_ID, 'blm_post_location_latitude', true );
	$blm_post_location_longitude = get_post_meta( $post_ID, 'blm_post_location_longitude', true );

	// Check location requirements
	if ( ! $blm_post_location_formatted || ! $blm_post_location_latitude || ! $blm_post_location_longitude ) {
		// Update response
		update_post_meta(
			$post_ID,
			'blm_savepost_response',
			wp_json_encode(
				array(
					'code'    => 0,
					'message' => 'A valid location was not selected',
				)
			)
		);

		return true;
	}

	// Gather post data
	setup_postdata( $post );

	// Format publish date
	$blm_publish_date = get_the_date( 'Y-m-d H:i:sP', $post_ID );

	// Check for custom publish date
	$blm_publish_date_custom = get_option( 'blm_setting_posttype_publishdate_' . $post_type );

	if ( $blm_publish_date_custom ) {
		$blm_publish_date_custom_value = get_post_meta( $post_ID, $blm_publish_date_custom, true );

		if ( ! $blm_publish_date_custom_value && isset( $_POST[ $blm_publish_date_custom ] ) ) {
			$blm_publish_date_custom_value = sanitize_text_field( $_POST[ $blm_publish_date_custom ] );
		}

		if ( $blm_publish_date_custom_value ) {
			// Format into date
			$blm_publish_date_custom_formatted = strtotime( $blm_publish_date_custom_value );

			if ( $blm_publish_date_custom_formatted ) {
				$blm_publish_date_custom_formatted = date( 'Y-m-d H:i:sP', $blm_publish_date_custom_formatted );

				if ( $blm_publish_date_custom_formatted ) {
					$blm_publish_date = $blm_publish_date_custom_formatted;
				}
			}
		}
	}

	// Check for custom fields
	$custom_fields = array();

	switch ( $blm_post_type ) {
		case 'event':
			// Get event end date
			$blm_end_date = get_option( 'blm_setting_posttype_enddate_' . $post_type );

			if ( $blm_end_date ) {
				$blm_end_date_value = get_post_meta( $post_ID, $blm_end_date, true );

				if ( $blm_end_date ) {
					// Format into date
					$blm_end_date_formatted = strtotime( $blm_end_date_value );

					if ( $blm_end_date_formatted ) {
						$blm_end_date_formatted = date( 'Y-m-d H:i:sP', $blm_end_date_formatted );

						if ( $blm_end_date_formatted ) {
							$custom_fields['end_date'] = $blm_end_date_formatted;
						}
					}
				}
			}

			break;
	}

	$custom_fields = wp_json_encode( $custom_fields );

	// Format expiration days
	$expiration_days        = 'default';
	$expiration_days_custom = get_option( 'blm_setting_posttype_expiration_' . $post_type );
	if ( $expiration_days_custom ) {
		$expiration_days = $expiration_days_custom;
	}

	// Format post data
	$query = array(
		'plugin_system'      => 'wordpress',
		'plugin_version'     => blm_lib_get_version(),
		'google_key'         => $blm_setting_google_api_key,
		'app_key'            => $blm_setting_bloom_api_key,
		'app_publisher'      => $blm_setting_bloom_publisher_key,
		'app_action'         => 'post_add',
		'key'                => get_post_meta( $post_ID, 'blm_post_key', true ),
		'date'               => $blm_publish_date,
		'expiration_days'    => $expiration_days,
		'type'               => $blm_post_type,
		'title'              => get_the_title( $post ),
		'content'            => get_the_excerpt( $post ),
		'content_full'       => $post->post_content,
		'location_address'   => $blm_post_location_formatted,
		'location_latitude'  => $blm_post_location_latitude,
		'location_longitude' => $blm_post_location_longitude,
		'url'                => get_permalink( $post ),
		'image_url'          => get_the_post_thumbnail_url( $post, 'large' ),
		'user_agent'         => $input['blm-ua'],
		'custom_fields'      => $custom_fields,
	);

	// Process Bloom API call
	$api_response = blm_lib_api_process( 'post', $query, true );

	// Handle API error
	if ( ! $api_response || ! isset( $api_response['code'] ) || ! isset( $api_response['message'] ) ) {
		blm_lib_error( 'api_jsondecode', $api_response );

		// Update response
		update_post_meta(
			$post_ID,
			'blm_savepost_response',
			wp_json_encode(
				array(
					'code'    => 0,
					'message' => 'Plugin system error'
				)
			)
		);

		return true;
	}

	// Handle type of response
	if ( 1 === (int)$api_response['code'] ) {
		// Save post key
		update_post_meta( $post_ID, 'blm_post_key', $api_response['data']['key'] );

		// Save post categories
		if ( isset( $api_response['data']['categories'] ) && ! empty( $api_response['data']['categories'] ) ) {
			update_post_meta( $post_ID, 'blm_post_categories', implode( ';', $api_response['data']['categories'] ) );
		}

		//Handle if post key is available to update despite the error
	} elseif ( isset( $api_response['data'] ) && isset( $api_response['data']['key'] ) && $api_response['data']['key'] ) {
		// Save post key
		update_post_meta( $post_ID, 'blm_post_key', $api_response['data']['key'] );
	}

	// Update response
	update_post_meta(
		$post_ID,
		'blm_savepost_response',
		wp_json_encode(
			array(
				'code'    => $api_response['code'],
				'message' => $api_response['message'],
			)
		)
	);

	return true;
}// blm_admin_post_save

/*
* blm_admin_post_validtype
* Check for a valid page type
*/
function blm_admin_post_validtype( $page ) {

	// Ignore if invalid page type
	if ( 'post.php' !== $page && 'post-new.php' !== $page ) {
		return false;
	}

	return true;
}//blm_admin_post_validtype

/*
* blm_admin_post_save_reset
* Reset the post's geotagging status
*/
function blm_admin_post_save_reset() {
	global $post_ID;

	//Remove post's geotagging status
	delete_post_meta( $post_ID, 'blm_savepost_response' );

	return true;
}// blm_admin_post_save_reset
