// Initialize Google geocoder
var blmGeocoder = null;
if (typeof( google ) !== undefined ) {
    blmGeocoder = new google.maps.Geocoder();
}

/**
 * Function: blmGeocode
 * Geocode an input
 */
function blmGeocode(blmLocationField, blmLocationResults, blmCallback)
{

    // Check requirements
    if (! blmLocationField || ! blmLocationResults ) {
        return false;
    }

    // Initialize
    blmLocationField   = document.getElementById(blmLocationField);
    blmLocationResults = document.getElementById(blmLocationResults);

    // Get address json results
    blmGeocoder.geocode(
        { 'address': blmLocationField.value },
        function ( blmGeocoderResults, blmGeocoderStatus ) {

            var blmLocationResultsDisplay = document.createElement('ul');

            if (blmGeocoderStatus === google.maps.GeocoderStatus.OK ) {
                // Calculate results length
                var blmResultsLimit = 5;

                // Iterate through results
                if (blmGeocoderResults.length > 0 ) {
                    var blmResultsCount = 0;
                    var blmIndex        = 0;

                    // Confirm that the next json result is defined and blmResultsCount under limit
                    while ( blmGeocoderResults[ blmIndex ] !== undefined && blmResultsCount < blmResultsLimit ) {
                        // Confirm that the result is a street address via looking at street address and route components
                        if (blmLocationCheck(blmGeocoderResults[ blmIndex ], 'address') 
                            || blmLocationCheck(blmGeocoderResults[ blmIndex ], 'intersection') 
                            || blmLocationCheck(blmGeocoderResults[ blmIndex ], 'premise') 
                            || blmLocationCheck(blmGeocoderResults[ blmIndex ], 'place') 
                        ) {
                        blmGeocoderResults[ blmIndex ].geometry = {
                            location: {
                                lat: blmGeocoderResults[ blmIndex ].geometry.location.lat(),
                                lng: blmGeocoderResults[ blmIndex ].geometry.location.lng()
                            }
                            };

                            // Add result item to list
                            var li_input = document.createElement('input');
                            li_input.setAttribute('type', 'hidden');
                            li_input.setAttribute('id', 'blm-result-select-' + blmIndex);
                            li_input.value = btoa(JSON.stringify(blmGeocoderResults[ blmIndex ]));

                            var li_a = document.createElement('a');
                            li_a.setAttribute('href', 'javascript:;');
                            li_a.setAttribute('onClick', 'blmReplaceInput( ' + blmIndex + ' )');
                            li_a.appendChild(document.createTextNode(blmGeocoderResults[ blmIndex ].formatted_address));

                            var li = document.createElement('li');
                            li.appendChild(li_input);
                            li.appendChild(li_a);
                            blmLocationResultsDisplay.appendChild(li);

                            // Increment count
                            blmResultsCount++;
                        }

                        // Increment iteration
                        blmIndex++;
                    }
                }
            }

            // Show results
            blmLocationResults.setAttribute('data-display', 1);

            // Check if results are found
            if (! blmLocationResultsDisplay.firstChild ) {
                blmLocationResultsDisplay = document.createElement('p');
                blmLocationResultsDisplay.appendChild(document.createTextNode('No street addresses found'));
            }

            // Throw results into HTML
            blmLocationResults.innerHTML = '';
            blmLocationResults.appendChild(blmLocationResultsDisplay);

            if (blmCallback) {
                blmCallback(blmLocationResultsDisplay);
            }

        }
    );

}// blmGeocode

/**
 * Function: blmReplaceInput
 * On click of a location result, put it in the input
 */
function blmReplaceInput( blmResultSelectId )
{

    // Select location
    var blmResult = JSON.parse(atob(document.getElementById('blm-result-select-' + blmResultSelectId).value));

    // Construct address components
    var blmAddressComponentsContainer = document.createElement('ul');
    var blmAddressComponents          = {
        street_number: '',
        route: '',
        locality: '',
        administrative_area_level_3: '',
        administrative_area_level_2: '',
        administrative_area_level_1: '',
        postal_code: '',
        country: ''
    };

    // Loop through address components of selected address
    for ( var i = 0; i < blmResult.address_components.length; i++ ) {
        // Get address component type
        var blmAddressComponentsType = blmResult.address_components[ i ].types;
        if (! blmAddressComponentsType ) {
            continue;
        }

        // Form HTML
        var blmAddressComponentsTypeDisplay = document.createElement('strong');
        blmAddressComponentsTypeDisplay.appendChild(document.createTextNode(blmAddressComponentsType[0].charAt(0).toUpperCase() + blmAddressComponentsType[0].replace(/_/g, ' ').substr(1) + ': '));
        blmAddressComponents[ blmAddressComponentsType[0] ] = blmResult.address_components[ i ].long_name;
        blmAddressComponent                                 = document.createElement('li');
        blmAddressComponent.appendChild(blmAddressComponentsTypeDisplay);
        blmAddressComponent.appendChild(document.createTextNode(blmAddressComponents[ blmAddressComponentsType[0] ]));
        blmAddressComponentsContainer.appendChild(blmAddressComponent);
    }

    blmAddressComponents = btoa(JSON.stringify(blmAddressComponents));
    var blmLocation      = blmResult.geometry.location;
    var blmLatitude      = blmLocation[ Object.keys(blmLocation)[0] ];
    var blmLongitude     = blmLocation[ Object.keys(blmLocation)[1] ];

    // Change location details to be saved and selected location title
    document.getElementById('blm-location-choice-value').innerHTML = '';
    document.getElementById('blm-location-choice-value').appendChild(document.createTextNode(blmResult.formatted_address));
    document.getElementById('blm-formatted-address').value  = blmResult.formatted_address;
    document.getElementById('blm-address-components').value = blmAddressComponents;
    document.getElementById('blm-latitude').value           = blmLatitude;
    document.getElementById('blm-longitude').value          = blmLongitude;
    document.getElementById('blm-location-results').setAttribute('data-display', 0);
    document.getElementById('blm-location-choice').setAttribute('data-display', 1);
    document.getElementById('blm-location-choice-components').innerHTML = '';

    if (blmAddressComponentsContainer.firstChild ) {
        document.getElementById('blm-location-choice-components').appendChild(blmAddressComponentsContainer);
    }

}// blmReplaceInput

/*
* Function: blmClearLocation
* Clear currently selected location
*/
function blmClearLocation()
{

    document.getElementById('blm-location-choice-value').innerHTML = '';
    document.getElementById('blm-formatted-address').value         = '';
    document.getElementById('blm-address-components').value        = '';
    document.getElementById('blm-latitude').value                  = '';
    document.getElementById('blm-longitude').value                 = '';
    document.getElementById('blm-location-choice').setAttribute('data-display', 0);

}// blmClearLocation

/*
* Function: blmLocationDetailsChange
* Show or hide the location details
*/
function blmLocationDetailsChange( blmDetailsRequest )
{

    if (blmDetailsRequest === 'show' ) {
        var blmDetailsDisplay = 'block';
        var blmDetailsText    = 'Hide details';
    } else {
        var blmDetailsDisplay = 'none';
        var blmDetailsText    = 'Show details';
    }

    document.getElementById('blm-location-choice-components').style.display = blmDetailsDisplay;
    document.getElementById('blm-location-details').setAttribute('onClick', "blmLocationDetailsChange('" + ( ( blmDetailsRequest === 'show' ) ? 'hide' : 'show' ) + "')");
    document.getElementById('blm-location-details').innerHTML = '';
    document.getElementById('blm-location-details').appendChild(document.createTextNode(blmDetailsText));

}// blmLocationDetailsChange

/*
* Function: blmLocationCheck
* Determine if given location is of given type
*/
function blmLocationCheck( blmLocation, blmLocationType )
{

    switch ( blmLocationType ) {
    case 'address':

        if ('street_number' === blmLocation.address_components[0].types[0] 
            && '' !== blmLocation.address_components[0].long_name 
            && 'route' === blmLocation.address_components[1].types[0] 
            && '' !== blmLocation.address_components[1].long_name 
        ) {
            return true;
        }

        if ('route' === blmLocation.address_components[0].types[0] 
            && '' !== blmLocation.address_components[0].long_name 
        ) {
            return true;
        }

            break;

    case 'intersection':

        if ('route' === blmLocation.address_components[0].types[0] 
            && '' !== blmLocation.address_components[0].long_name 
            && 'intersection' === blmLocation.types[0] 
        ) {
            return true;
        }

            break;

    case 'premise':

        if ('premise' === blmLocation.address_components[0].types[0] 
            && '' !== blmLocation.address_components[0].long_name 
            && 'street_number' === blmLocation.address_components[1].types[0] 
            && '' !== blmLocation.address_components[1].long_name 
        ) {
            return true;
        }

            break;

    case 'place':

        if (('park' === blmLocation.address_components[0].types[0] 
            || 'airport' === blmLocation.address_components[0].types[0] 
            || 'point_of_interest' === blmLocation.address_components[0].types[0] 
            || 'natural_feature' === blmLocation.address_components[0].types[0]) 
            && '' !== blmLocation.address_components[0].long_name 
        ) {
            return true;
        }

            break;
    }

    return false;

}//blmLocationCheck
