<?php //Library: lib.php

/*
* blm_lib_api_process
* Call the initial API request
*/
function blm_lib_api_process( $method_url, $query, $decode_to_array = false ) {

	$url = 'https://api.bloom.li/' . $method_url;

	$response = wp_safe_remote_get(
		$url,
		array(
			'method'              => 'POST',
			'timeout'             => apply_filters( 'http_request_timeout', 30, $url ),
			'redirection'         => apply_filters( 'http_request_redirection_count', 5, $url ),
			'httpversion'         => apply_filters( 'http_request_version', '1.1', $url ),
			'user-agent'          => apply_filters( 'http_headers_useragent', 'WordPress/' . get_bloginfo( 'version' ) . '; ' . get_bloginfo( 'url' ), $url ),
			'blocking'            => true,
			'body'                => $query,
			'compress'            => false,
			'decompress'          => true,
			'sslverify'           => false,
			'stream'              => false,
			'limit_response_size' => null,
		)
	);

	if ( ! is_array( $response ) || is_wp_error( $response ) ) {
		return wp_json_encode(
			array(
				'code'    => 0,
				'message' => 'An error occurred',
				'data' => $response
			)
		);
	}

	// Decode response
	if ( $response['body'] !== false ) {
		$response['body'] = json_decode( utf8_encode( wp_strip_all_tags( $response['body'] ) ), $decode_to_array );
	}

	//Check successful and return result
	if ( $decode_to_array ) {
		if ( isset( $response['body']['success'] ) && $response['body']['success'] ) {
			return $response['body']['data'];
		}
	} elseif ( isset( $response['body']->success ) && $response['body']->success ) {
		return $response['body']->data;
	}

	return wp_json_encode(
		array(
			'code'    => 0,
			'message' => 'An error occurred',
			'data' => $response
		)
	);
}// blm_lib_api_process

/*
* blm_lib_keyword_strpad
* Pad the number of a keyword's count
*/
function blm_lib_keyword_strpad( $count ) {

	return str_pad( $count, 5, 0, STR_PAD_LEFT );
}// blm_lib_keyword_strpad

/*
* blm_lib_keyword_format
* Update the keyword to an acceptable format
*/
function blm_lib_keyword_format( $keyword ) {

	$result = str_replace( ' ', '-', $keyword );

	return preg_replace( '/[^\w-]/', '', $result );
}// blm_lib_keyword_format

/*
* blm_lib_error
* Error reporting
*/
function blm_lib_error( $type, $data ) {

	// Process Bloom API call
	blm_lib_api_process(
		'info',
		array(
			'app_key'    => get_option( 'blm_setting_bloom_api_key' ),
			'app_user'   => get_option( 'blm_setting_bloom_publisher_key' ),
			'app_action' => 'error_wp_api',
			'data'       => array(
				'type'    => $type,
				'content' => $data,
			),
		)
	);
}// blm_lib_error

/*
* blm_lib_get_version
* Get version of the Bloom for Publishers plugin
*/
function blm_lib_get_version() {
	$plugin_data = get_plugin_data( plugin_dir_path( __FILE__ ) . 'bloom.php' );
	return $plugin_data['Version'];
}// blm_lib_get_version
