<?php //Post: post.php

add_action( 'wp_head', 'blm_post_head' );
add_shortcode( 'bloom', 'blm_post_map_shortcode' );
add_filter( 'the_content', 'blm_post_map_append' );
add_filter( 'the_content', 'blm_post_feed_append' );

/*
* blm_post_head
* Add post's metadata to head section
*/
function blm_post_head() {
	// Retrieves the stored value from the database
	$blm_post_location_formatted = get_post_meta( get_the_ID(), 'blm_post_location_formatted', true );
	$blm_post_location_longitude = get_post_meta( get_the_ID(), 'blm_post_location_longitude', true );
	$blm_post_location_latitude  = get_post_meta( get_the_ID(), 'blm_post_location_latitude', true );
	$blm_post_key                = get_post_meta( get_the_ID(), 'blm_post_key', true );
	$blm_post_categories         = get_post_meta( get_the_ID(), 'blm_post_categories', true );

	// Only show tags if inside post
	if ( is_single() && $blm_post_location_formatted && $blm_post_location_latitude && $blm_post_location_longitude ) {
		// Checks and displays the retrieved value
		echo '<meta property="geo:formatted_address" content="' . esc_attr( htmlentities( $blm_post_location_formatted, ENT_QUOTES ) ) . '" />' . "\n";
		echo '<meta property="geo:latitude" content="' . esc_attr( $blm_post_location_latitude ) . '" />' . "\n";
		echo '<meta property="geo:longitude" content="' . esc_attr( $blm_post_location_longitude ) . '" />' . "\n";

		// If was posted to Bloom, display its key
		if ( $blm_post_key ) {
			echo '<meta property="bloom:key" content="' . esc_attr( $blm_post_key ) . '" />' . "\n";
		}

		// If categories were provided by Bloom
		if ( $blm_post_categories ) {
			echo '<meta property="bloom:categories" content="' . esc_attr( $blm_post_categories ) . '" />' . "\n";
		}
	}
}// blm_post_head

/*
*blm_post_map_shortcode
*Get a map shortcode and translate it to display a map
*/
function blm_post_map_shortcode( $atts ) {

	// Check requirements
	if ( empty( $atts ) ||
	! isset( $atts['type'] ) ||
	'map' !== $atts['type'] ||
	! get_post_meta( get_the_ID(), 'blm_post_location_longitude', true ) ||
	! get_post_meta( get_the_ID(), 'blm_post_location_latitude', true ) ) {
		return '';
	}

	// Determine size
	$atts_size_w = 600;
	if ( isset( $atts['size'] ) ) {
		switch ( $atts['size'] ) {
			case 'small':
				$atts_size_w = 300;
				break;
		}
	}

	$post_key = get_post_meta( get_the_ID(), 'blm_post_key', true );
	if ( $post_key ) {
		$url_param = 'akey=' . rawurlencode( $post_key );
	} else {
		$url_param = 'url=' . rawurlencode( get_permalink() );
	}

	return '<iframe src="' . esc_url( 'https://embed.bloom.li/article/map?' . $url_param ) . '" name="Map" style="border:none;visibility:visible;width: 100% !important;max-width:' . esc_attr( $atts_size_w ) . 'px;height:235px"></iframe>';
}// blm_post_map_shortcode

/*
*blm_post_map_append
*Append the article's map image to the end of its content
*/
function blm_post_map_append( $blm_content ) {

	// Check page requirements
	if ( 'true' !== get_option( 'blm_setting_map_append_enabled' ) ||
	has_shortcode( $blm_content, 'bloom' ) ||
	! is_single() ||
	! get_post_meta( get_the_ID(), 'blm_post_location_longitude', true ) ||
	! get_post_meta( get_the_ID(), 'blm_post_location_latitude', true ) ) {
		return $blm_content;
	}

	// Get append settings
	$blm_append_settings = array(
		'size'     => get_option( 'blm_setting_map_append_size' ),
		'position' => get_option( 'blm_setting_map_append_position' ),
		'margin'   => '',
	);

	// Get append size
	switch ( $blm_append_settings['size'] ) {
		case 'small':
			$blm_append_settings['size']   = 'square';
			$blm_append_settings['size_w'] = 300;
			break;

		case 'large':
		default:
			$blm_append_settings['size']   = 'rect';
			$blm_append_settings['size_w'] = 600;
			break;
	}

	$post_key = get_post_meta( get_the_ID(), 'blm_post_key', true );
	if ( $post_key ) {
		$url_param = 'akey=' . rawurlencode( $post_key );
	} else {
		$url_param = 'url=' . rawurlencode( get_permalink() );
	}

	if ( 'top' === $blm_append_settings['position'] ) {
		$blm_append_settings['margin'] = 'margin-bottom: 20px;';
	}

	$blm_append_map = '<iframe src="' . esc_url( 'https://embed.bloom.li/article/map?' . $url_param ) . '" name="Map" style="border:none;visibility:visible;width: 100% !important;max-width:' . esc_attr( $blm_append_settings['size_w'] ) . 'px;height:235px;' . esc_attr( $blm_append_settings['margin'] ) . '"></iframe>';

	switch ( $blm_append_settings['position'] ) {
		case 'top':
			return $blm_append_map . $blm_content;
			break;

		case 'bottom':
		default:
			return $blm_content . $blm_append_map;
			break;
	}
}// blm_post_map_append

/*
*blm_post_feed_append
*Append a news feed of content nearby the article's location content
*/
function blm_post_feed_append( $blm_content ) {

	// Check page requirements
	if ( 'true' !== get_option( 'blm_setting_feed_append_enabled' ) ||
	! get_option( 'blm_setting_feed_id' ) ||
	! is_single() ||
	! get_post_meta( get_the_ID(), 'blm_post_location_longitude', true ) ||
	! get_post_meta( get_the_ID(), 'blm_post_location_latitude', true ) ) {
		return $blm_content;
	}

	$blm_append_feed = '<iframe src="' . esc_url( 'https://embed.bloom.li/plugin/' . get_option( 'blm_setting_feed_id' ) . '?url=' . get_permalink( get_the_ID() ) ) . '" name="Nearby Feed" style="border:none;visibility:visible;width:100% !important;height:350px"></iframe>';

	return $blm_content . $blm_append_feed;
}// blm_post_feed_append
