var $, bloom_nns, bloom_nns_iv_pulse = null;
var bloom_nns_domain = 'https://embed.bloom.li';
var bloom_nns_delay = 2000;
var bloom_nns_meta = {
    lat : {
        key : 'lat',
        val : ''
    },
    lng : {
        key : 'lng',
        val : ''
    },
    address : {
        key : 'address',
        val_encoded : '',
        val : ''
    },
    akey : {
        key : 'akey',
        val : ''
    }
};
var bloom_nns_remote = {
    params : [],
    synced : false
};

/**
* Function: onload
* Actions to perform on window load
*/
jQuery(
    function () {
        $ = jQuery.noConflict();
        bloomnnsLoadDoc();
    } 
);//Onload

/**
 * Function: bloomnnsLoadDoc
 * Load the plugin when document is ready
 */
function bloomnnsLoadDoc()
{

    setTimeout(bloomnnsLoad, bloom_nns_delay);

    //Button listeners
    $(document).on(
        'click touchend', 'blm-link', function (e) {
            e.stopPropagation();
            e.preventDefault();
            bloomnnsTrigger(this, 'BP-001-03');
        }
    );

    $(document).on(
        'click touchend', 'blm-button', function (e) {
            e.stopPropagation();
            e.preventDefault();
            bloomnnsTrigger(this, 'BP-001-02');
        } 
    );

    $(document).on(
        'click touchend', '#blm-s-local-intro-button, #blm-i-current', function (e) {
            if (document.getElementsByTagName('bloom')[0].getAttribute('data-geolocation') == '1' ) {
                bloomnnsGeolocation(e);
                $(this).addClass('loading');

                if ($(this).attr('id') === 'blm-i-current' ) {
                    $(this).find('span').attr('data-has-message', 'true').text('Loading...');
                }

            } else {
                e.stopPropagation();
                e.preventDefault();
                bloomnnsLaunch(2, 'BP-001-06');
            }
        }
    );

    $(document).on(
        'click touchend', '#blm-s-local-intro-search button', function (e) {

            e.stopPropagation();
            e.preventDefault();

            //Ignore if no input
            if (!$('[name="blm-s-local-intro-field"]').val() ) {
                return false;
            }

            //Determine if custom input (not meta default)
            var bloom_nns_custom_input = null;
            if ($('[name="blm-s-local-intro-field"]').val().trim().toLowerCase() !== bloom_nns_meta.address.val.trim().toLowerCase() ) {
                bloom_nns_custom_input = $('[name="blm-s-local-intro-field"]').val();
            }

            //Submit location request
            $(this).parent().addClass('loading');
            bloomnnsLoadRemoteContent(null, bloom_nns_custom_input);
            setTimeout(
                function () {
                    bloomnnsLaunch(2, 'BP-001-07');
                }, bloom_nns_delay
            );

        }
    );

    $(document).on(
        'click touchend', '#blm-s-local-intro-more', function (e) {
            e.stopPropagation();
            e.preventDefault();
            bloomnnsLoadRemoteContent();
            bloomnnsLaunch(2, 'BP-001-08');
        }
    );

    $(document).on(
        'click touchend', '#blm-s-local-banner-close', function (e) {
            e.stopPropagation();
            e.preventDefault();
            document.getElementById('blm-s-local-banner').removeAttribute('data-type');
            document.getElementById('blm-s-local-banner').setAttribute('data-active', '0');
        }
    );

    $(document).on(
        'click touchend', '[href*="bloom_search="]', function (e) {
            e.stopPropagation();
            e.preventDefault();
            bloomnnsUrlRequest($(this).attr('href'));
        }
    );

    //Scroll listener
    $(window).on(
        'scroll', function () {

            var bloom_nns_container = document.getElementById('blm-search');

            //Ignore if not initialized, open, or has scroll opened
            if (bloom_nns_container !== null && (bloom_nns_container.getAttribute('data-open') == '1' || bloom_nns_container.getAttribute('data-has-scrollopened') == 'true') ) {
                return true;
            }

            var bloom_nns_scroll_position = (document.documentElement.scrollTop || document.body.scrollTop ) + window.innerHeight;
            var bloom_nns_scroll_height = document.documentElement.scrollHeight;

            //Ignore if not near bottom of page
            if (bloom_nns_scroll_position < bloom_nns_scroll_height || (bloom_nns_scroll_height - bloom_nns_scroll_position) > 200 ) {
                return true;
            }

            //Open plugin
            bloomnnsLaunch(1, 'BP-001-04');

            //Mark as opened by scrolling
            setTimeout(
                function () {

                    //Get container if not yet initialized
                    if (bloom_nns_container === null ) {
                        bloom_nns_container = document.getElementById('blm-search');
                    }

                    //Ignore if container cannot be initialized
                    if (bloom_nns_container === null ) {
                        return false;
                    }

                    //Mark as has opened via scroll
                    bloom_nns_container.setAttribute('data-has-scrollopened', 'true');

                },
                ( bloom_nns_container ? 0 : 5000 )
            );

        }
    );

}//bloomnnsLoadDoc

/**
 * Function: bloomnnsLoad
 * Load the search plugin
 */
function bloomnnsLoad()
{

    //Define bloom element
    bloom_nns = document.getElementsByTagName('bloom');

    //Check requirements
    if (! bloom_nns ) {
        return true;
    }

    bloom_nns = bloom_nns[0];

    //Initialize
    bloomnnsGetMetadata();

    //Add footer and CSS
    var bloom_nns_el_icon = document.createElement('div');
    bloom_nns_el_icon.setAttribute('id', 'blm-icon');
    bloom_nns_el_icon.setAttribute('data-has-tooltip', 'true');
    bloom_nns_el_icon.setAttribute('data-pulse', 'true');
    bloom_nns_el_icon.style.cssText = 'background-color:#' + bloom_nns.getAttribute('data-color') + ' !important';
    var bloom_nns_el_tooltip = document.createElement('div');
    bloom_nns_el_tooltip.setAttribute('id', 'blm-i-tooltip');
    bloom_nns_el_tooltip.style.cssText = 'display: none;';
    bloom_nns_el_tooltip.innerText = 'Search Nearby';
    var bloom_nns_el_pulse = document.createElement('div');
    bloom_nns_el_pulse.setAttribute('id', 'blm-i-pulse');
    bloom_nns_el_pulse.style.cssText = 'border-color:#' + bloom_nns.getAttribute('data-color') + ' !important';
    var bloom_nns_el_circle = document.createElement('div');
    bloom_nns_el_circle.setAttribute('id', 'blm-i-circle');
    bloom_nns_el_circle.innerHTML = '<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="times" class="svg-inline--fa fa-times fa-w-11" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 352 512"><path fill="currentColor" d="M242.72 256l100.07-100.07c12.28-12.28 12.28-32.19 0-44.48l-22.24-22.24c-12.28-12.28-32.19-12.28-44.48 0L176 189.28 75.93 89.21c-12.28-12.28-32.19-12.28-44.48 0L9.21 111.45c-12.28 12.28-12.28 32.19 0 44.48L109.28 256 9.21 356.07c-12.28 12.28-12.28 32.19 0 44.48l22.24 22.24c12.28 12.28 32.2 12.28 44.48 0L176 322.72l100.07 100.07c12.28 12.28 32.2 12.28 44.48 0l22.24-22.24c12.28-12.28 12.28-32.19 0-44.48L242.72 256z"></path></svg>';
    bloom_nns_el_icon.appendChild(bloom_nns_el_tooltip);
    bloom_nns_el_icon.appendChild(bloom_nns_el_pulse);
    bloom_nns_el_icon.appendChild(bloom_nns_el_circle);
    bloom_nns.appendChild(bloom_nns_el_icon);
    bloom_nns_el_button_current = document.createElement('div');
    bloom_nns_el_button_current.setAttribute('id', 'blm-i-current');
    bloom_nns_el_button_current.innerHTML = '<span>Get current location</span><svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="location-arrow" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512" class="svg-inline--fa fa-location-arrow fa-w-16 fa-2x"><path fill="currentColor" d="M444.52 3.52L28.74 195.42c-47.97 22.39-31.98 92.75 19.19 92.75h175.91v175.91c0 51.17 70.36 67.17 92.75 19.19l191.9-415.78c15.99-38.39-25.59-79.97-63.97-63.97z" class=""></path></svg>';
    bloom_nns.appendChild(bloom_nns_el_button_current);
    bloom_nns.setAttribute('data-open', '0');
    bloom_nns.setAttribute('data-has-opened', '0');

    setTimeout(
        function () {

            bloom_nns.setAttribute('data-loaded', 'true');
            bloom_nns.setAttribute('data-has-opened-before', (bloomnnsGetCookie('bloom_search_popup') ? '1' : '0'));

            document.getElementById('blm-icon').addEventListener('touchend', bloomnnsIconAction, true);
            document.getElementById('blm-icon').addEventListener('click', bloomnnsIconAction, true);

            //Launch plugin if not yet opened
            if (bloom_nns.getAttribute('data-seconds') && !bloomnnsGetCookie('bloom_search_popup') ) {
                setTimeout(
                    function () {
                        if (document.getElementById('blm-search') === null ) {
                            bloomnnsLaunch(1, 'BP-001-01');
                        }
                    }, bloom_nns.getAttribute('data-seconds') * 1000
                );
            }

        }, 100
    );

    //Pulse animation
    var bloom_nns_pulse_num = 3;
    var bloom_nns_pulse_duration = 2;
    var bloom_nns_pulse_delay = 30;
    var bloom_nns_pulse_active = bloom_nns_pulse_num * bloom_nns_pulse_duration;    

    setTimeout(
        function () {
            bloom_nns_el_icon.setAttribute('data-pulse', 'false');
        }, bloom_nns_pulse_active * 1000 
    );

    bloom_nns_iv_pulse = setInterval(
        function () {
            bloom_nns_el_icon.setAttribute('data-pulse', 'true');
            setTimeout(
                function () {
                    bloom_nns_el_icon.setAttribute('data-pulse', 'false');
                }, bloom_nns_pulse_active * 1000 
            );
        }, ( bloom_nns_pulse_active + bloom_nns_pulse_delay ) * 1000 
    );

    //Check for auto-open request
    bloomnnsUrlRequest($(location).attr('href'));

}//bloomnnsLoad

/**
 * Function: bloomnnsLaunch
 * Launch the search toolbar
 */
function bloomnnsLaunch( layout, source )
{

    //Open plugin
    if (document.getElementById('blm-search') !== null ) {

        //Open active plugin based on request
        if (layout || document.getElementById('blm-search').getAttribute('data-open') === '0' ) {
            bloomnnsOpen(layout);
        } else {
            bloomnnsClose();
        }

    } else {

        //Initialize plugin
        bloomnnsInit(layout, source);

    }

    //Stop pulse animation
    if (bloom_nns_iv_pulse ) {
        clearInterval(bloom_nns_iv_pulse);
    }

}//bloomnnsLaunch

/**
 * Function: bloomnnsInit
 * Initialize search toolbar
 */
function bloomnnsInit( layout, source )
{

    //Check requirements
    if (! bloom_nns ) {
        return false;
    }

    //Get source of event
    if (source ) {
        bloomnnsUrlParamModify('source', source);
    }

    //Generate HTML
    bloom_nns_el_header = document.createElement('div');
    bloom_nns_el_header.setAttribute('id', 'blm-s-h');
    bloom_nns_el_header.style.cssText = 'background-color:#' + bloom_nns.getAttribute('data-color') + ' !important';
    bloom_nns_el_header_title = document.createElement('span');
    bloom_nns_el_header_title.innerText = 'Explore News Nearby';
    bloom_nns_el_header_landscape = document.createElement('div');
    bloom_nns_el_header_landscape.setAttribute('id', 'blm-s-h-landscape');
    bloom_nns_el_header_landscape.style.cssText = 'background-color:#' + bloom_nns.getAttribute('data-color');
    bloom_nns_el_header_landscape_balls = document.createElement('div');
    bloom_nns_el_header_landscape_balls.setAttribute('id', 'blm-s-h-landscape-balls');
    bloom_nns_el_header_landscape_balls.style.cssText = 'background-color:#' + bloom_nns.getAttribute('data-color');
    bloom_nns_el_header_landscape_ball = document.createElement('div');
    bloom_nns_el_header_landscape_ball.setAttribute('class', 'blm-s-h-landscape-ball');
    bloom_nns_el_header.appendChild(bloom_nns_el_header_title);
    bloom_nns_el_header.appendChild(bloom_nns_el_header_landscape);
    bloom_nns_el_header_landscape_balls.appendChild(bloom_nns_el_header_landscape_ball);
    bloom_nns_el_header_landscape_balls.appendChild(bloom_nns_el_header_landscape_ball.cloneNode(true));
    bloom_nns_el_header_landscape_balls.appendChild(bloom_nns_el_header_landscape_ball.cloneNode(true));
    bloom_nns_el_header_landscape_balls.appendChild(bloom_nns_el_header_landscape_ball.cloneNode(true));
    bloom_nns_el_header.appendChild(bloom_nns_el_header_landscape_balls);

    bloom_nns_el_content = document.createElement('div');
    bloom_nns_el_content.setAttribute('class', 'blm-s-c');

    bloom_nns_el_content_local = document.createElement('div');
    bloom_nns_el_content_local.setAttribute('id', 'blm-s-local');
    bloom_nns_el_content_local.innerHTML = '<div id="blm-s-local-banner"><div id="blm-s-local-banner-text"></div><a href="javascript:;" title="Close" id="blm-s-local-banner-close"><svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="times" class="svg-inline--fa fa-times fa-w-11" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 352 512"><path fill="currentColor" d="M242.72 256l100.07-100.07c12.28-12.28 12.28-32.19 0-44.48l-22.24-22.24c-12.28-12.28-32.19-12.28-44.48 0L176 189.28 75.93 89.21c-12.28-12.28-32.19-12.28-44.48 0L9.21 111.45c-12.28 12.28-12.28 32.19 0 44.48L109.28 256 9.21 356.07c-12.28 12.28-12.28 32.19 0 44.48l22.24 22.24c12.28 12.28 32.2 12.28 44.48 0L176 322.72l100.07 100.07c12.28 12.28 32.2 12.28 44.48 0l22.24-22.24c12.28-12.28 12.28-32.19 0-44.48L242.72 256z"></path></svg></a></div>';

    bloom_nns_el_content_remote = document.createElement('div');
    bloom_nns_el_content_remote.setAttribute('id', 'blm-s-remote');
    bloom_nns_el_content.appendChild(bloom_nns_el_content_remote);

    //Load iframe if requested
    if (!layout || layout === 1 ) {
        bloom_nns_el_content_local_intro = document.createElement('div');
        bloom_nns_el_content_local_intro.setAttribute('id', 'blm-s-local-intro');
        bloom_nns_el_content_local_intro_title = document.createElement('div');
        bloom_nns_el_content_local_intro_title.setAttribute('id', 'blm-s-local-intro-title');
        bloom_nns_el_content_local_intro_title.innerText = 'Discover news happening near places you care about';
        bloom_nns_el_content_local_intro_title.style.cssText = 'color:#' + bloom_nns.getAttribute('data-color');
        bloom_nns_el_content_local_intro_options = document.createElement('div');
        bloom_nns_el_content_local_intro_options.setAttribute('id', 'blm-s-local-intro-options');
        bloom_nns_el_content_local_intro_options_button = document.createElement('a');
        bloom_nns_el_content_local_intro_options_button.setAttribute('href', 'javascript:;');
        bloom_nns_el_content_local_intro_options_button.setAttribute('id', 'blm-s-local-intro-button');
        bloom_nns_el_content_local_intro_options_button.innerHTML = 'News near me<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="location-arrow" class="svg-inline--fa fa-location-arrow fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="currentColor" d="M444.52 3.52L28.74 195.42c-47.97 22.39-31.98 92.75 19.19 92.75h175.91v175.91c0 51.17 70.36 67.17 92.75 19.19l191.9-415.78c15.99-38.39-25.59-79.97-63.97-63.97z"></path></svg><svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="spinner" class="svg-inline--fa fa-spinner fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="currentColor" d="M304 48c0 26.51-21.49 48-48 48s-48-21.49-48-48 21.49-48 48-48 48 21.49 48 48zm-48 368c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zm208-208c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zM96 256c0-26.51-21.49-48-48-48S0 229.49 0 256s21.49 48 48 48 48-21.49 48-48zm12.922 99.078c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.491-48-48-48zm294.156 0c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.49-48-48-48zM108.922 60.922c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.491-48-48-48z"></path></svg>';
        bloom_nns_el_content_local_intro_options_button.style.cssText = 'background-color:#' + bloom_nns.getAttribute('data-color');
        bloom_nns_el_content_local_intro_options_search = document.createElement('div');
        bloom_nns_el_content_local_intro_options_search.setAttribute('id', 'blm-s-local-intro-search');
        bloom_nns_el_content_local_intro_options_search_input = document.createElement('input');
        bloom_nns_el_content_local_intro_options_search_input.setAttribute('type', 'text');
        bloom_nns_el_content_local_intro_options_search_input.setAttribute('name', 'blm-s-local-intro-field');
        bloom_nns_el_content_local_intro_options_search_input.setAttribute('placeholder', 'Search a place near you...');

        bloom_nns_el_content_local_intro_options_search_button = document.createElement('button');
        bloom_nns_el_content_local_intro_options_search_button.setAttribute('type', 'submit');
        bloom_nns_el_content_local_intro_options_search_button.innerHTML = '<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="search" class="svg-inline--fa fa-search fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="currentColor" d="M505 442.7L405.3 343c-4.5-4.5-10.6-7-17-7H372c27.6-35.3 44-79.7 44-128C416 93.1 322.9 0 208 0S0 93.1 0 208s93.1 208 208 208c48.3 0 92.7-16.4 128-44v16.3c0 6.4 2.5 12.5 7 17l99.7 99.7c9.4 9.4 24.6 9.4 33.9 0l28.3-28.3c9.4-9.4 9.4-24.6.1-34zM208 336c-70.7 0-128-57.2-128-128 0-70.7 57.2-128 128-128 70.7 0 128 57.2 128 128 0 70.7-57.2 128-128 128z"></path></svg><svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="spinner" class="svg-inline--fa fa-spinner fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="currentColor" d="M304 48c0 26.51-21.49 48-48 48s-48-21.49-48-48 21.49-48 48-48 48 21.49 48 48zm-48 368c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zm208-208c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zM96 256c0-26.51-21.49-48-48-48S0 229.49 0 256s21.49 48 48 48 48-21.49 48-48zm12.922 99.078c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.491-48-48-48zm294.156 0c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.49-48-48-48zM108.922 60.922c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.491-48-48-48z"></path></svg>';
        bloom_nns_el_content_local_intro_options_search_button.style.cssText = 'background-color:#' + bloom_nns.getAttribute('data-color');

        if (bloom_nns_meta.address.val ) {
            bloom_nns_el_content_local_intro_options_search.innerHTML = '<span id="blm-s-local-intro-search-icon-label">Default: Location of this page</span><svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="file-alt" class="svg-inline--fa fa-file-alt fa-w-12" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><path fill="currentColor" d="M224 136V0H24C10.7 0 0 10.7 0 24v464c0 13.3 10.7 24 24 24h336c13.3 0 24-10.7 24-24V160H248c-13.2 0-24-10.8-24-24zm64 236c0 6.6-5.4 12-12 12H108c-6.6 0-12-5.4-12-12v-8c0-6.6 5.4-12 12-12h168c6.6 0 12 5.4 12 12v8zm0-64c0 6.6-5.4 12-12 12H108c-6.6 0-12-5.4-12-12v-8c0-6.6 5.4-12 12-12h168c6.6 0 12 5.4 12 12v8zm0-72v8c0 6.6-5.4 12-12 12H108c-6.6 0-12-5.4-12-12v-8c0-6.6 5.4-12 12-12h168c6.6 0 12 5.4 12 12zm96-114.1v6.1H256V0h6.1c6.4 0 12.5 2.5 17 7l97.9 98c4.5 4.5 7 10.6 7 16.9z"></path></svg>';
            bloom_nns_el_content_local_intro_options_search.setAttribute('data-has-meta', 'true');
            bloom_nns_el_content_local_intro_options_search_input.setAttribute('value', bloom_nns_meta.address.val);
        }

        bloom_nns_el_content_local_intro_options_search.appendChild(bloom_nns_el_content_local_intro_options_search_input);
        bloom_nns_el_content_local_intro_options_search.appendChild(bloom_nns_el_content_local_intro_options_search_button);
        bloom_nns_el_content_local_intro_options_more = document.createElement('div');
        bloom_nns_el_content_local_intro_options_more.setAttribute('id', 'blm-s-local-intro-more');
        bloom_nns_el_content_local_intro_options_more_link = document.createElement('a');
        bloom_nns_el_content_local_intro_options_more_link.setAttribute('href', 'javascript:;');
        bloom_nns_el_content_local_intro_options_more_link.innerHTML = 'More options<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="angle-down" class="svg-inline--fa fa-angle-down fa-w-10" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512"><path fill="currentColor" d="M143 352.3L7 216.3c-9.4-9.4-9.4-24.6 0-33.9l22.6-22.6c9.4-9.4 24.6-9.4 33.9 0l96.4 96.4 96.4-96.4c9.4-9.4 24.6-9.4 33.9 0l22.6 22.6c9.4 9.4 9.4 24.6 0 33.9l-136 136c-9.2 9.4-24.4 9.4-33.8 0z"></path></svg>';
        bloom_nns_el_content_local_intro_options_more.appendChild(bloom_nns_el_content_local_intro_options_more_link);
        bloom_nns_el_content_local_intro_options.appendChild(bloom_nns_el_content_local_intro_options_button);
        bloom_nns_el_content_local_intro_options.appendChild(bloom_nns_el_content_local_intro_options_search);
        bloom_nns_el_content_local_intro_options.appendChild(bloom_nns_el_content_local_intro_options_more);
        bloom_nns_el_content_local_intro.appendChild(bloom_nns_el_content_local_intro_title);
        bloom_nns_el_content_local_intro.appendChild(bloom_nns_el_content_local_intro_options);
        bloom_nns_el_content_local.appendChild(bloom_nns_el_content_local_intro);
        bloom_nns_el_content.appendChild(bloom_nns_el_content_local);

    } else {
        bloomnnsLoadRemoteContent(bloom_nns_el_content_remote);
    }

    bloom_nns_el_footer = document.createElement('div');
    bloom_nns_el_footer.setAttribute('id', 'blm-s-f');
    bloom_nns_el_footer.style.cssText = 'border-color: #' + bloom_nns.getAttribute('data-color');
    bloom_nns_el_footer_attribution = document.createElement('a');
    bloom_nns_el_footer_attribution.setAttribute('href', 'https://www.bloom.li');
    bloom_nns_el_footer_attribution.setAttribute('title', 'Bloom');
    bloom_nns_el_footer_attribution.setAttribute('target', '_blank');
    bloom_nns_el_footer_attribution.innerText = 'Experience provided by Bloom';
    bloom_nns_el_footer_arrow = document.createElement('span');
    bloom_nns_el_footer_arrow_inner = document.createElement('span');
    bloom_nns_el_footer_arrow_inner.style.cssText = 'background-color: #' + bloom_nns.getAttribute('data-color');
    bloom_nns_el_footer_arrow.appendChild(bloom_nns_el_footer_arrow_inner);
    bloom_nns_el_footer.appendChild(bloom_nns_el_footer_attribution);
    bloom_nns_el_footer.appendChild(bloom_nns_el_footer_arrow);

    var bloom_nns_el_container = document.createElement('div');
    bloom_nns_el_container.setAttribute('id', 'blm-search');
    bloom_nns_el_container.setAttribute('data-color', bloom_nns.getAttribute('data-color'));
    bloom_nns_el_container.appendChild(bloom_nns_el_header);
    bloom_nns_el_container.appendChild(bloom_nns_el_content);
    bloom_nns_el_container.appendChild(bloom_nns_el_footer);
    document.getElementsByTagName('body')[0].appendChild(bloom_nns_el_container);

    //Display plugin
    setTimeout(
        function () {

            //Set plugin layout
            if (layout ) {
                bloomnnsSetLayout(layout);
            } else {
                bloomnnsSetLayout(1);
            }

            //Add geolocation if supported by browser
            bloomnnsTechSupports(
                'geolocation', function ( r ) {
                    document.getElementsByTagName('bloom')[0].setAttribute('data-geolocation', (r === true ? '1' : '0'));
                }
            );

            bloomnnsOpen(layout);

            setTimeout(
                function () {
                    document.getElementById('blm-s-h-landscape-balls').setAttribute('data-formation', '1');
                },
                300
            );

        }, 100
    );

}//bloomnnsInit

/**
 * Function: bloomnnsIconAction
 * Icon click listener
 */
function bloomnnsIconAction(e)
{

    e.stopPropagation();
    e.preventDefault();

    //If plugin is not opened
    if (document.getElementById('blm-search') === null || document.getElementById('blm-search').getAttribute('data-open') === '0' ) {

        //If has loaded remote layout, open remote
        if (document.getElementById('blm-s-iframe-content') ) {
            bloomnnsLaunch(2, 'BP-001-01');

        } else { //Open local layout
            bloomnnsLaunch(1);
        }

    } else {
        bloomnnsClose();
    }

}//bloomnnsIconAction

//Key up listener
document.addEventListener('keyup', bloomnnsKeyUp);

/**
 * Function: bloomnnsKeyUp
 * Handle search close request
 */
function bloomnnsKeyUp( e )
{

    //Ignore if plugin not initialized
    if (document.getElementById('blm-search') === null ) {
        return true;
    }

    e = e || window.event;

    //Close requests
    if (e.keyCode === 27 ) {

        if (document.getElementById('blm-search').getAttribute('data-open') === '1' ) {
            bloomnnsClose();
        }

        if (document.getElementById('blm-map-screen') !== null && document.getElementById('blm-map-screen').getAttribute('data-display') === '1' ) {
            bloomnnsMapClose();
        }

        //Input requests
    } else if (document.activeElement.getAttribute('name') === 'blm-s-local-intro-field' ) {

        //If enter key
        if (e.keyCode == 13 ) {

            //Ignore if no input
            if (! $('[name="blm-s-local-intro-field"]').val() ) {
                return false;
            }

            //Submit location request
            document.getElementById('blm-s-local-intro-search').classList.add('loading');
            bloomnnsLoadRemoteContent(null, $('[name="blm-s-local-intro-field"]').val());
            setTimeout(
                function () {
                    bloomnnsLaunch(2, 'BP-001-07');
                }, bloom_nns_delay
            );

        } else {

            //Disable page meta address if changed
            setTimeout(
                function () {
                    if ($('[name="blm-s-local-intro-field"]').val().trim().toLowerCase() === bloom_nns_meta.address.val.trim().toLowerCase() ) {
                        document.getElementById('blm-s-local-intro-search').setAttribute('data-has-meta', 'true');
                    } else {
                        document.getElementById('blm-s-local-intro-search').setAttribute('data-has-meta', 'false');
                    }
                }, 300
            );

        }

    }

}//bloomnnsKeyUp

/**
 * Function: bloomnnsOpen
 * Open the search plugin
 */
function bloomnnsOpen( layout )
{

    document.getElementsByTagName('body')[0].setAttribute('data-bloom-open', '1');
    document.getElementsByTagName('bloom')[0].setAttribute('data-open', '1');
    document.getElementsByTagName('bloom')[0].setAttribute('data-has-opened', '1');
    document.getElementById('blm-search').setAttribute('data-open', '1');

    //Set cookie
    bloomnnsSetCookie('bloom_search_popup');

    if (layout ) {
        bloomnnsSetLayout(layout);
    }

}//bloomnnsOpen

/**
 * Function: bloomnnsClose
 * Close the search plugin
 */
function bloomnnsClose()
{

    //Update layout
    bloomnnsSetLayout(0);

}//bloomnnsClose

/**
 * Function: bloomnnsGetMetadata
 * Get the location of the page
 */
function bloomnnsGetMetadata()
{

    var p, c;

    //Get metadata properties
    $('meta').each(
        function () {

            p = $(this).attr('property');
            c = $(this).attr('content');

            //Check requirements
            if (! p || ! c ) { 
                return true;
            }

            //Store geo metadata
            switch(p){
            case 'geo:latitude':
                bloom_nns_meta.lat.val = c;
                break;

            case 'geo:longitude':
                bloom_nns_meta.lng.val = c;
                break;

            case 'geo:formatted_address':
                bloom_nns_meta.address.val = c;
                bloom_nns_meta.address.val_encoded = encodeURIComponent(c);
                break;

            case 'bloom:key':
                bloom_nns_meta.akey.val = c;
                break;

            default:
                break;

            }

            return true;

        } 
    );

    //Handle requirements
    if (! bloom_nns_meta.lat.val || ! bloom_nns_meta.lng.val ) {
        bloom_nns_meta.lat.val = '';
        bloom_nns_meta.lng.val = '';
        bloom_nns_meta.address.val = '';
        return true;
    }

    //Format and add parameters
    bloom_nns_meta.lat.val = encodeURI(bloom_nns_meta.lat.val);
    bloom_nns_meta.lng.val = encodeURI(bloom_nns_meta.lng.val);
    bloomnnsUrlParamModify(bloom_nns_meta.akey.key, bloom_nns_meta.akey.val);
    bloomnnsUrlParamModify(bloom_nns_meta.lat.key, bloom_nns_meta.lat.val);
    bloomnnsUrlParamModify(bloom_nns_meta.lng.key, bloom_nns_meta.lng.val);
    bloomnnsUrlParamModify(bloom_nns_meta.address.key, bloom_nns_meta.address.val_encoded);

}//bloomnnsGetMetadata

/**
 * Function: bloomnnsGeolocation
 * Get the location of a user via web browser geolocation
 */
function bloomnnsGeolocation(e)
{
    //Handle event
    if (e ) {
        e.stopPropagation();
        e.preventDefault();
    }

    //Return error if browser doesn't support geolocation
    if (! navigator.geolocation ) {
        bloomnnsGeolocationResponse({ code : 4 });
        return false;
    }

    //Get current position
    navigator.geolocation.getCurrentPosition(
        function ( position ) {
            var bloom_nns_geocoder = new google.maps.Geocoder();
            var bloom_nns_latlng = new google.maps.LatLng(position.coords.latitude, position.coords.longitude);
            bloom_nns_geocoder.geocode(
                { 'latLng': bloom_nns_latlng }, function ( results, status ) {

                    //Handle geolocation result
                    if (results && results.length > 0 ) {

                        bloomnnsGeolocationResponse(
                            {
                                code : 5,
                                loc : [
                                    'geodata_lat=' + encodeURI(results[0].geometry.location.lat()),
                                    'geodata_lng=' + encodeURI(results[0].geometry.location.lng()),
                                    'geodata_address=' + encodeURIComponent(results[0].formatted_address)
                                ]
                            }
                        );

                    } else {
                        bloomnnsGeolocationResponse({ code : 0 });
                    }

                    //Set layout
                    if (bloomnnsGetLayout() == '2' ) {

                        //Reload layout with new remote parameters
                        bloomnnsSetLayout(2);

                        var bloom_nns_current = document.getElementById('blm-i-current');

                        if (bloom_nns_current !== null ) {
                            setTimeout(
                                function () {
                                    bloom_nns_current.parentNode.removeChild(bloom_nns_current);
                                }, bloom_nns_delay
                            );
                        }

                    } else {

                        setTimeout(
                            function () {
                                document.getElementById('blm-s-local-intro-button').classList.remove('loading');
                                bloomnnsSetLayout(2);
                            }, bloom_nns_delay
                        );

                    }

                } 
            );
        },
        function ( error ) {
            bloomnnsGeolocationResponse({ code : error.code });
        }
    );

}//bloomnnsGeolocation

/**
 * Function: bloomnnsGeolocationResponse
 * Handle response from geolocation input
 */
function bloomnnsGeolocationResponse( result )
{

    //Display message if error
    if (result.code !== 5 ) {

        if (bloomnnsGetLayout() == '1' ) {
            document.getElementById('blm-s-local-banner').setAttribute('data-type', 'error');
            document.getElementById('blm-s-local-banner').setAttribute('data-active', '1');
            document.getElementById('blm-s-local-banner-text').innerText = 'Could not get your location';
            document.getElementById('blm-s-local-intro-button').classList.remove('loading');
        } else {
            var bloom_nns_current = document.getElementById('blm-i-current');
            bloom_nns_current.setAttribute('data-status', 'error');
            bloom_nns_current.classList.remove('loading');
            bloom_nns_current.querySelectorAll('span')[0].textContent = 'Could not get your location';
            bloom_nns_current.querySelectorAll('span')[0].removeAttribute('data-has-message');
        }

        return true;
    }

    //Add geolocation parameters
    if (result.loc ) {
        bloomnnsUrlParamModify(null, result.loc);
    }
    bloomnnsUrlParamModify('geocode', result.code);

    //Update remote content
    bloomnnsLoadRemoteContent();

    //Hide local geolocation link and loading message
    setTimeout(
        function () {
            document.getElementsByTagName('bloom')[0].setAttribute('data-geolocation', '0');
            document.getElementById('blm-i-current').classList.remove('loading');
            document.getElementById('blm-s-local-intro-button').classList.remove('loading');
        }, bloom_nns_delay
    );

}//bloomnnsGeolocationResponse

/**
 * Function: bloomnnsLoadRemoteContent
 * Load remote content
 */
function bloomnnsLoadRemoteContent( container, input )
{

    //Ignore if remote is synced
    if (bloom_nns_remote.synced ) {
        return false;
    }

    //Get Google API key
    if (bloom_nns.getAttribute('data-google-key') ) {
        bloomnnsUrlParamModify('google_key', bloom_nns.getAttribute('data-google-key'));
    }

    //Get input
    if (input ) {
        bloomnnsUrlParamModify('input', input);
    }

    //Get frame settings
    var bloom_nns_remote_frame = document.getElementById('blm-s-iframe-content');
    var bloom_nns_remote_frame_src = bloom_nns_domain + '/plugin/' + bloom_nns.getAttribute('data-plugin') + '?' + bloom_nns_remote.params.join('&');

    //Create or update frame
    if (bloom_nns_remote_frame ) {

        //Update frame
        bloom_nns_remote_frame.setAttribute('src', bloom_nns_remote_frame_src);

    } else {

        //Create frame
        bloom_nns_remote_frame = document.createElement('iframe');
        bloom_nns_remote_frame.setAttribute('allowtransparency', 'true');
        bloom_nns_remote_frame.setAttribute('id', 'blm-s-iframe-content');
        bloom_nns_remote_frame.style.cssText = 'border:none;visibility:visible;width:100%;height:100%;';
        bloom_nns_remote_frame.setAttribute('src', bloom_nns_remote_frame_src);

        //Load remote container if needed
        if (! container ) {
            container = document.getElementById('blm-s-remote');
        }

        container.appendChild(bloom_nns_remote_frame);

    }

    //Set status as synced
    bloom_nns_remote.synced = true;

}//bloomnnsLoadRemoteContent

/**
 * Function: bloomnnsSetLayout
 * Resize the plugin layout
 */
function bloomnnsSetLayout( layout )
{

    //Determine layout
    if (layout == undefined ) {
        if (bloomnnsGetLayout() == '1' ) {
            layout = 2;
        } else {
            layout = 1;
        }
    }

    //Load remote content if remote layout (2) requested
    if (layout === 2 ) {
        bloomnnsLoadRemoteContent();
    }

    //Set layout
    document.getElementsByTagName('bloom')[0].setAttribute('data-layout', layout);
    document.getElementById('blm-search').setAttribute('data-layout', layout);

    //Set plugin setting
    document.getElementsByTagName('bloom')[0].setAttribute('data-open', (layout === 0 ? '0' : '1'));
    document.getElementsByTagName('body')[0].setAttribute('data-bloom-open', (layout === 0 ? '0' : '1'));
    document.getElementById('blm-search').setAttribute('data-open', (layout === 0 ? '0' : '1'));

}//bloomnnsSetLayout

/**
 * Function: bloomnnsGetLayout
 * Get the plugin layout
 */
function bloomnnsGetLayout()
{

    //Check requirements
    if (! document.getElementById('blm-search') ) {
        return null;
    }

    return document.getElementById('blm-search').getAttribute('data-layout');

}//bloomnnsGetLayout

/**
 * Function: bloomnnsTrigger
 * Event listener for custom links
 */
function bloomnnsTrigger( item, search_code )
{

    //Ignore if no trigger type set
    if (! $(item).attr('data-type') ) {
        return false;
    }

    switch( $(item).attr('data-type') ) {
    //Launch plugin
    case 'search':
        bloomnnsLaunch(2, search_code);
        break;

    //Launch map
    case 'map':
        if (! bloom_nns_meta.akey.val ) {
            $(item).css('display', 'none');
            break;
        }

        bloomnnsMapLaunch();

        break;

    default:
        break;

    }

}//bloomnnsTrigger

/**
 * Function: bloomnnsMapLaunch
 * Launch a map
 */
function bloomnnsMapLaunch()
{

    //Handle if map was previously launched
    if (document.getElementById('blm-map-screen') !== null ) {

        //Display map
        document.getElementById('blm-map-screen').setAttribute('data-display', '1');

    } else {

        //Ignore if no article key
        if (! bloom_nns_meta.akey.val ) {
            return false;
        }

        //Create and display map
        var bloom_nns_map = document.createElement('div');
        bloom_nns_map.setAttribute('id', 'blm-map-screen');
        bloom_nns_map.setAttribute('data-display', '1');
        var bloom_nns_map_content = document.createElement('div');
        bloom_nns_map_content.setAttribute('id', 'blm-map-screen-content');
        var bloom_nns_map_close = document.createElement('div');
        bloom_nns_map_close.setAttribute('id', 'blm-map-screen-close');
        bloom_nns_map_close.innerHTML = '<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="times" class="svg-inline--fa fa-times fa-w-11" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 352 512"><path fill="currentColor" d="M242.72 256l100.07-100.07c12.28-12.28 12.28-32.19 0-44.48l-22.24-22.24c-12.28-12.28-32.19-12.28-44.48 0L176 189.28 75.93 89.21c-12.28-12.28-32.19-12.28-44.48 0L9.21 111.45c-12.28 12.28-12.28 32.19 0 44.48L109.28 256 9.21 356.07c-12.28 12.28-12.28 32.19 0 44.48l22.24 22.24c12.28 12.28 32.2 12.28 44.48 0L176 322.72l100.07 100.07c12.28 12.28 32.2 12.28 44.48 0l22.24-22.24c12.28-12.28 12.28-32.19 0-44.48L242.72 256z"></path></svg>';
        bloom_nns_map_content.appendChild(bloom_nns_map_close);
        bloom_nns_map_frame = document.createElement('iframe');
        bloom_nns_map_frame.setAttribute('src', bloom_nns_domain + '/article/map?' + bloom_nns_meta.akey.key + '=' + bloom_nns_meta.akey.val + '&size=rect&zoom=16&source=BP-007-01');
        bloom_nns_map_frame.setAttribute('name', 'Map');
        bloom_nns_map_frame.style.cssText = 'border:none;visibility:visible;width:100% !important;max-width:600px;height:235px;';
        bloom_nns_map_content.appendChild(bloom_nns_map_frame);
        bloom_nns_map.appendChild(bloom_nns_map_content);
        document.getElementsByTagName('body')[0].appendChild(bloom_nns_map);

        //Close map listener
        bloom_nns_map_close.addEventListener('click', bloomnnsMapClose); 

    }

}//bloomnnsMapLaunch

/**
 * Function: bloomnnsMapClose
 * Close a map
 */
function bloomnnsMapClose()
{

    //Get map screen
    var bloom_map_screen = document.getElementById('blm-map-screen');

    //Check requirements
    if (bloom_map_screen === null ) {
        return false;
    }

    //Close map
    bloom_map_screen.setAttribute('data-display', '0');

}//bloomnnsMapClose

/**
 * Function: bloomnnsUrlRequest
 * Perform a request provided with the given URL
 */
function bloomnnsUrlRequest(url)
{

    //Handle requirements
    if (!url || url.indexOf('?') === -1 || url.indexOf('bloom_search=') === -1 ) {
        return null;
    }

    //Get URL parameters
    url_params = url.split('?');

    //Parse URL parameters
    url_params_list = bloomnnsUrlParamParse(url_params[1]);

    //Check requirements
    if (!url_params_list.bloom_search ) {
        return null;
    }

    //Perform requested action
    switch(url_params_list.bloom_search ) {

    case 'prompt':
        bloomnnsLaunch(1, 'BP-001-05');
        break;

    case 'open':
        bloomnnsLaunch(2, 'BP-001-05');
        break;

    case 'nearby':
        bloomnnsLaunch(1, 'BP-001-05');

        setTimeout(
            function () {

                //If plugin is not opened or remote layout not loaded
                if (document.getElementById('blm-search') === null || document.getElementById('blm-search').getAttribute('data-open') === '0' || document.getElementById('blm-s-iframe-content') === null) {
                    $('#blm-s-local-intro-button').trigger('click');
                }else{
                    $('#blm-i-current').trigger('click');
                }

            }, 500
        );

        break;

    }

    return true;

}//bloomnnsUrlRequest

/**
 * Function: bloomnnsUrlParamParse
 * Parse URL parameters
 */
function bloomnnsUrlParamParse(query)
{

    var bloom_nns_query_vars = query.split('&');
    var bloom_nns_query_string = {};

    for (var i = 0; i < bloom_nns_query_vars.length; i++) {
        var bloom_nns_query_pair = bloom_nns_query_vars[i].split('=');
        var bloom_nns_query_key = decodeURIComponent(bloom_nns_query_pair[0]);
        var bloom_nns_query_value = decodeURIComponent(bloom_nns_query_pair[1]);

        if (typeof bloom_nns_query_string[bloom_nns_query_key] === 'undefined' ) {
            bloom_nns_query_string[bloom_nns_query_key] = decodeURIComponent(bloom_nns_query_value);
        } else if (typeof bloom_nns_query_string[bloom_nns_query_key] === 'string' ) {
            bloom_nns_query_string[bloom_nns_query_key] = [bloom_nns_query_string[bloom_nns_query_key], decodeURIComponent(bloom_nns_query_value)];
        } else {
            bloom_nns_query_string[bloom_nns_query_key].push(decodeURIComponent(bloom_nns_query_value));
        }
    }

    return bloom_nns_query_string;

}//bloomnnsUrlParamParse

function bloomnnsUrlParamModify(k, v)
{

    //Update URL parameter
    if (v === false ) {
        if (!bloom_nns_remote.params[k] ) {
            return false;
        }
        delete bloom_nns_remote.params[k];
    }else if (typeof v !== 'function' && typeof v !== 'object' ) {
        if (bloom_nns_remote.params[k] ) {
            bloom_nns_remote.params[k] = v;
        }else{
            bloom_nns_remote.params.push(k + '=' + v);
        }
    }else if (v.constructor === Array ) {
        bloom_nns_remote.params = bloom_nns_remote.params.concat(v);
    }else{
        return false;
    }

    //Update URL sync
    bloom_nns_remote.synced = false;

    return true;

}//bloomnnsUrlParamModify

/**
 * Function: bloomnnsTechSupports
 * Check if the browser supports a function
 */
function bloomnnsTechSupports( type, callback )
{

    //Get browser
    var bloom_nns_browser = navigator.userAgent.match(/(opera|chrome|safari|firefox|msie|trident(?=\/))\/?\s*(\d+)/i) || [];

    //Check if Chrome and client is not https
    var bloom_nns_browser_chromestrict = false;
    if (bloom_nns_browser[1] === 'Chrome' && bloom_nns_browser[2] > 49 && $(location).attr('protocol') !== 'https:' ) {
        bloom_nns_browser_chromestrict = true;
    }

    //If geolocation is not supported
    if (type === 'geolocation' && ( typeof( google ) === undefined || navigator.geolocation === undefined || bloom_nns_browser_chromestrict ) ) {
        return callback(false);
    }

    return callback(true);

}//bloomnnsTechSupports

/**
 * Function: bloomnnsSetCookie
 * Set a cookie
 */
function bloomnnsSetCookie()
{

    //Determine expiration date
    var bloom_nns_cookie_date = new Date();
    bloom_nns_cookie_date.setTime(bloom_nns_cookie_date.getTime() + ( 30 * 24 * 60 * 60 * 1000 ));

    //Set cookie
    document.cookie = "bloom_search_popup=opened;expires=" + bloom_nns_cookie_date.toUTCString() + ";path=/";

}//bloomnnsSetCookie

/**
 * Function: bloomnnsGetCookie
 * Get the requested cookie
 */
function bloomnnsGetCookie( name )
{

    var bloom_nns_cookie_name = name + "=";
    var bloom_nns_cookie = decodeURIComponent(document.cookie).split(';');

    for( var i = 0; i < bloom_nns_cookie.length; i++ ) {
        var bloom_nns_cookie_part = bloom_nns_cookie[i].trimStart();
        if (bloom_nns_cookie_part.indexOf(bloom_nns_cookie_name) == 0 ) {
            return bloom_nns_cookie_part.substring(bloom_nns_cookie_name.length, bloom_nns_cookie_part.length);
        }
    }

    return false;

}//bloomnnsGetCookie
