<?php //Search: search.php

global $blm_settings, $blm_version;
$blm_settings = array();
$blm_version = '1.5.2';

add_action( 'init', 'blm_redirect' );
add_action( 'wp_footer', 'blm_search_footer', 100 );
add_action( 'wp_enqueue_scripts', 'blm_search_scripts' );

/*
* blm_redirect
* Apply redirect if settings are applicable and current URL is shortlink
*/
function blm_redirect() {

    //Check for applicable redirect settings
    if ( isset($_SERVER) && 
    isset($_SERVER['REQUEST_URI']) && 
    ( '/nearby' === sanitize_text_field( $_SERVER['REQUEST_URI'] ) || '/nearby/' === sanitize_text_field( $_SERVER['REQUEST_URI'] ) ) && 
    'true' === get_option('blm_setting_search_shortlink') ) {

        //Handle nearby redirect
        if( wp_redirect( esc_url( get_site_url() ) . '?bloom_search=nearby', '301' ) ) {
            exit;
        }

    }

}//blm_redirect

/*
* blm_search_footer
* Add search to the footer of the website
*/
function blm_search_footer() {
	// Check requirements
	if ( ! blm_search_auth() ) {
		return true;
	}

	// Get plugin settings
	$blm_settings = blm_plugin_settings_read();

	if ( ! $blm_settings ) {
		return false;
	}

    //Format auto-open seconds
    $seconds_attr = false;
	$seconds_setting = esc_attr( get_option( 'blm_setting_search_open_seconds' ) );
	if ( $seconds_setting !== false && is_numeric( $seconds_setting ) ) {
        $seconds_attr = true;
	}

	// Add plugin
	echo '<bloom data-plugin="' . esc_attr( $blm_settings['key'] ) . '" data-color="' . esc_attr( $blm_settings['color'] ) . '"' . ($seconds_attr ? ' data-seconds="' . (int)$seconds_setting . '"' : '') . ' data-google-key="' . esc_attr( get_option( 'blm_setting_google_api_key' ) ) . '"></bloom>';
}// blm_search_footer

/*
* blm_plugin_settings_update
* Save plugin settings
*/
function blm_plugin_settings_update() {
	// Get application style
	global $blm_settings;
	$api_response = blm_lib_api_process(
		'info',
		array(
			'app_key'       => get_option( 'blm_setting_bloom_api_key' ),
			'publisher_key' => get_option( 'blm_setting_bloom_publisher_key' ),
			'app_action'    => 'get_search_plugin',
		)
	);

	// Handle error
	if ( ! $api_response || ! $api_response->success) {
		return false;
	}

	// Further decode response
	$blm_settings = $api_response->message;
	$blm_settings = (array) $blm_settings;
	$blm_settings = wp_json_encode( $blm_settings );

	// Handle error
	if ( ! $blm_settings ) {
		return false;
	}

	// Save settings
	update_option( 'blm_setting_search_settings', $blm_settings );

	return $blm_settings;
}// blm_plugin_settings_update

/*
* blm_plugin_settings_read
* Get the plugin settings
*/
function blm_plugin_settings_read() {
	// Get settings
	$blm_settings = get_option( 'blm_setting_search_settings' );

	// Handle if settings don't exist
	if ( ! $blm_settings ) {
		// Get settings from Bloom
		$blm_settings_new = blm_plugin_settings_update();

		// Handle valid settings
		if ( $blm_settings_new ) {
			$blm_settings = $blm_settings_new;
		}
	}

	// Decode settings
	$blm_settings = json_decode( $blm_settings, true );

	return $blm_settings;
}// blm_plugin_settings_read

/*
* blm_search_scripts
* Add CSS and JS to the plugin
*/
function blm_search_scripts() {
	// Check requirements
	if ( ! blm_search_auth() ) {
		return true;
	}

	// Set Google script if key provided
	$blm_setting_google_api_key = esc_attr( get_option( 'blm_setting_google_api_key' ) );
	if ( $blm_setting_google_api_key ) {
		wp_enqueue_script( 'blm_search_js_geo', esc_url( 'https://maps.googleapis.com/maps/api/js?key=' . $blm_setting_google_api_key ) );
	}

	// Set other scripts
	global $blm_version;
	wp_enqueue_script( 'blm_search_js', plugins_url( 'js/search.js', __FILE__ ), array( 'jquery' ), $blm_version, true );
	wp_enqueue_style( 'blm_search_css', plugins_url( 'css/search.css', __FILE__ ), array(), $blm_version, 'all' );
}// blm_search_scripts

/*
*blm_search_auth
*Authenticate the display of the plugin
*/
function blm_search_auth() {
	//Ignore if plugin key is not provided
	if ( ! get_option( 'blm_setting_bloom_api_key' ) ) {
		return false;
	}

	//Ignore if search is not enabled or if preview is disabled or if user is not logged in
	if ( 'true' === get_option( 'blm_setting_search_enabled' ) ) {
		return true;
	}

	if ( 'false' === get_option( 'blm_setting_search_preview' ) ) {
		return false;
	}

	if ( ! is_user_logged_in() ) {
		return false;
	}

	//Get logged in user
	$user = wp_get_current_user();

	//Compare against allowed roles
	$role_diff = array_udiff(
		$user->roles,
		array( 'administrator', 'editor', 'contributor', 'author' ),
		'strcasecmp'
	);

	if ( empty( $role_diff ) ) {
		return true;
	}

	return true;
}//blm_search_auth
